@@ -3,7 +3,7 @@ from typing import Iterable, Union, Mapping
 
 from flask_restful import Resource, fields, marshal
 
-from metadata_service.proxy import neo4j_proxy
+from metadata_service.proxy import get_proxy_client
 
 tag_fields = {
     'tag_name': fields.String,
@@ -18,12 +18,12 @@ tag_usage_fields = {
 
 class TagAPI(Resource):
     def __init__(self) -> None:
-        self.neo4j = neo4j_proxy.get_neo4j()
+        self.client = get_proxy_client()
         super(TagAPI, self).__init__()
 
     def get(self) -> Iterable[Union[Mapping, int, None]]:
         """
         API to fetch all the existing tags with usage.
         """
-        tag_usages = self.neo4j.get_tags()
+        tag_usages = self.client.get_tags()
         return marshal({'tag_usages': tag_usages}, tag_usage_fields), HTTPStatus.OK
